@@ -5,7 +5,6 @@
 #include <sys/stat.h>
 
 struct ioloop;
-struct iostream_fd;
 
 struct istream {
 	uoff_t v_offset;
@@ -42,10 +41,6 @@ typedef void istream_callback_t(void *context);
 struct istream *i_stream_create_fd(int fd, size_t max_buffer_size);
 /* The fd is set to -1 immediately to avoid accidentally closing it twice. */
 struct istream *i_stream_create_fd_autoclose(int *fd, size_t max_buffer_size);
-/* Autoclose the fd once ref's refcount drops to 0. This function increases the
-   refcount, so the caller is expected to unref it as well. */
-struct istream *i_stream_create_fd_ref_autoclose(struct iostream_fd *ref,
-						 size_t max_buffer_size);
 /* Open the given path only when something is actually tried to be read from
    the stream. */
 struct istream *i_stream_create_file(const char *path, size_t max_buffer_size);
@@ -65,8 +60,6 @@ i_stream_create_copy_from_data(const void *data, size_t size);
 	i_stream_create_copy_from_data((buf)->data, (buf)->used)
 #define i_stream_create_copy_from_string(str) \
 	i_stream_create_copy_from_data(str_data(str), str_len(str))
-/* Create a no-operation wrapper to allow input to be used as child stream. */
-struct istream *i_stream_create_noop(struct istream *input);
 struct istream *i_stream_create_limit(struct istream *input, uoff_t v_size);
 struct istream *i_stream_create_range(struct istream *input,
 				      uoff_t v_offset, uoff_t v_size);
@@ -108,9 +101,6 @@ int i_stream_get_fd(struct istream *stream);
    The readable_fd is preserved. Assert-crashes if source doesn't have a
    file descriptor. */
 void i_stream_copy_fd(struct istream *dest, struct istream *source);
-/* Set error for istream. */
-void i_stream_set_error(struct istream *stream, int stream_errno,
-			const char *fmt, ...) ATTR_FORMAT(3, 4);
 /* Returns error string for the last error. It also returns "EOF" in case there
    is no error, but eof is set. Otherwise it returns "<no error>". */
 const char *i_stream_get_error(struct istream *stream);
@@ -242,7 +232,7 @@ i_stream_read_more(struct istream *stream, const unsigned char **data_r,
    indicated limit. Use this function to prevent growing the stream buffer
    beyond what the application is willing to read immediately. Since this
    function doesn't fully prevent buffering beyond the limit, the amount of data
-   actually buffered can exceed the limit. However, *size_r will always be <=
+   actually buffered can exceed the limit. However, *size_r will allways be <=
    limit to avoid confusion. */
 int i_stream_read_limited(struct istream *stream, const unsigned char **data_r,
 			  size_t *size_r, size_t limit);
